@@ -143,6 +143,7 @@ def audit() -> None:
         description="audit the Python environment for dependencies with known vulnerabilities",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
+    dep_source_args = parser.add_mutually_exclusive_group()
     parser.add_argument("-V", "--version", action="version", version=f"%(prog)s {__version__}")
     parser.add_argument(
         "-l",
@@ -150,7 +151,7 @@ def audit() -> None:
         action="store_true",
         help="show only results for dependencies in the local environment",
     )
-    parser.add_argument(
+    dep_source_args.add_argument(
         "-r",
         "--requirement",
         type=argparse.FileType("r"),
@@ -216,8 +217,28 @@ def audit() -> None:
     parser.add_argument(
         "--timeout", type=int, default=15, help="set the socket timeout"  # Match the `pip` default
     )
+    dep_source_args.add_argument(
+        "--path",
+        type=Path,
+        action="append",
+        dest="paths",
+        default=[],
+        help="restrict to the specified installation path for auditing packages; "
+        "this option can be used multiple times",
+    )
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        dest="verbose",
+        action="store_true",
+        help="give more output; this setting overrides the `PIP_AUDIT_LOGLEVEL` variable and is "
+        "equivalent to setting it to `debug`",
+    )
 
     args = parser.parse_args()
+    if args.verbose:
+        logging.root.setLevel("DEBUG")
+
     logger.debug(f"parsed arguments: {args}")
 
     service = args.vulnerability_service.to_service(args.timeout, args.cache_dir)
@@ -232,7 +253,7 @@ def audit() -> None:
             req_files: List[Path] = [Path(req.name) for req in args.requirements]
             source = RequirementSource(req_files, ResolveLibResolver(args.timeout, state), state)
         else:
-            source = PipSource(local=args.local)
+            source = PipSource(local=args.local, paths=args.paths)
 
         auditor = Auditor(service, options=AuditOptions(dry_run=args.dry_run))
 
