@@ -5,15 +5,14 @@ Closely adapted from `resolvelib`'s examples, which are copyrighted by the `reso
 authors under the ISC license.
 """
 
-import os
+import itertools
 from email.message import EmailMessage
 from email.parser import BytesParser
 from io import BytesIO
 from operator import attrgetter
-from platform import python_version
-from tarfile import TarFile
+from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import BinaryIO, List, Optional, Set, cast
+from typing import BinaryIO, Iterator, List, Optional, Set, cast
 from urllib.parse import urlparse
 from zipfile import ZipFile
 
@@ -26,9 +25,11 @@ from packaging.version import Version
 from resolvelib.providers import AbstractProvider
 
 from pip_audit._state import AuditState
+from pip_audit._util import python_version
 from pip_audit._virtual_env import VirtualEnv
 
-PYTHON_VERSION = Version(python_version())
+# TODO: Final[Version] when our minimal Python is 3.8.
+PYTHON_VERSION: Version = python_version()
 
 
 class Candidate:
@@ -41,6 +42,7 @@ class Candidate:
     def __init__(
         self,
         name: str,
+        filename: Path,
         version: Version,
         url: str,
         extras: Set[str],
@@ -53,6 +55,7 @@ class Candidate:
         """
 
         self.name = canonicalize_name(name)
+        self.filename = filename
         self.version = version
         self.url = url
         self.extras = extras
@@ -68,8 +71,8 @@ class Candidate:
         A string representation for `Candidate`.
         """
         if not self.extras:
-            return f"<{self.name}=={self.version}>"
-        return f"<{self.name}[{','.join(self.extras)}]=={self.version}>"
+            return f"<{self.name}=={self.version} wheel={self.is_wheel}>"
+        return f"<{self.name}[{','.join(self.extras)}]=={self.version} wheel={self.is_wheel}>"
 
     @property
     def metadata(self) -> EmailMessage:
@@ -138,23 +141,15 @@ class Candidate:
         """
         Extracts the metadata for this candidate, if it's a source distribution.
         """
+
         response: requests.Response = requests.get(self.url, timeout=self.timeout)
         response.raise_for_status()
-        data = response.content
+        sdist_data = response.content
         metadata = EmailMessage()
 
         with TemporaryDirectory() as pkg_dir:
-            if self.state is not None:
-                self.state.update_state(
-                    f"Extracting source distribution for {self.name} ({self.version})"
-                )  # pragma: no cover
-
-            # Extract archive onto the disk
-            with TarFile.open(fileobj=BytesIO(data), mode="r:gz") as t:
-                # The directory is the first member in a tarball
-                names = t.getnames()
-                pkg_name = names[0]
-                t.extractall(pkg_dir)
+            sdist = Path(pkg_dir) / self.filename.name
+            sdist.write_bytes(sdist_data)
 
             if self.state is not None:
                 self.state.update_state(
@@ -162,11 +157,8 @@ class Candidate:
                     f"({self.version})"
                 )  # pragma: no cover
 
-            # Put together a full path of where the source distribution is
-            pkg_path = os.path.join(pkg_dir, pkg_name)
-
             with TemporaryDirectory() as ve_dir:
-                ve = VirtualEnv(["-e", pkg_path], self.state)
+                ve = VirtualEnv([str(sdist)], self.state)
                 ve.create(ve_dir)
 
                 if self.state is not None:
@@ -181,7 +173,9 @@ class Candidate:
         return metadata
 
 
-def get_project_from_pypi(project, extras, timeout: Optional[int], state: Optional[AuditState]):
+def get_project_from_pypi(
+    project, extras, timeout: Optional[int], state: Optional[AuditState]
+) -> Iterator[Candidate]:
     """Return candidates created from the project name and extras."""
     url = "https://pypi.org/simple/{}".format(project)
     response: requests.Response = requests.get(url, timeout=timeout)
@@ -213,15 +207,21 @@ def get_project_from_pypi(project, extras, timeout: Optional[int], state: Option
                 # which we'll then skip via the exception handler.
                 (name, version) = parse_sdist_filename(filename)
                 is_wheel = False
+
+            # TODO: Handle compatibility tags?
+            yield Candidate(
+                name,
+                Path(filename),
+                version,
+                url=url,
+                extras=extras,
+                is_wheel=is_wheel,
+                timeout=timeout,
+                state=state,
+            )
         except Exception:
             continue
 
-        # TODO: Handle compatibility tags?
-
-        yield Candidate(
-            name, version, url=url, extras=extras, is_wheel=is_wheel, timeout=timeout, state=state
-        )
-
 
 class PyPIProvider(AbstractProvider):
     """
@@ -271,14 +271,27 @@ class PyPIProvider(AbstractProvider):
         # Need to pass the extras to the search, so they
         # are added to the candidate at creation - we
         # treat candidates as immutable once created.
-        candidates = (
-            candidate
-            for candidate in get_project_from_pypi(identifier, extras, self.timeout, self.state)
-            if candidate.version not in bad_versions
-            and all(candidate.version in r.specifier for r in requirements)
+        candidates = sorted(
+            [
+                candidate
+                for candidate in get_project_from_pypi(identifier, extras, self.timeout, self.state)
+                if candidate.version not in bad_versions
+                and all(candidate.version in r.specifier for r in requirements)
+            ],
+            key=attrgetter("version", "is_wheel"),
+            reverse=True,
         )
-        # We want to prefer more recent versions and prioritize wheels
-        return sorted(candidates, key=attrgetter("version", "is_wheel"), reverse=True)
+
+        # If we have multiple candidates for a single version and some are wheels,
+        # yield only the wheels. This keeps us from wasting a large amount of
+        # dependency search time when comparing wheels against source distributions.
+        for _, candidates in itertools.groupby(candidates, key=attrgetter("version")):
+            candidate = next(candidates)
+            yield candidate
+            if candidate.is_wheel:
+                yield from (c for c in candidates if c.is_wheel)
+            else:
+                yield from candidates
 
     def is_satisfied_by(self, requirement, candidate):
         """
